<?php

namespace Drupal\block_class\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Core\Url;
use Symfony\Component\HttpFoundation\RedirectResponse;

/**
 * Form for Block Class Settings.
 */
class BlockClassBulkOperationsForm extends ConfigFormBase {

  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'block_class_admin_bulk_operations';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'block_class.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $form['operation'] = [
      '#title' => $this->t("Operation"),
      '#type' => 'select',
      '#options' => [
        'insert' => $this->t('Insert class(es)'),
        'update' => $this->t('Update class'),
        'delete' => $this->t('Delete all block classes'),
      ],
    ];

    $form['classes_to_be_added'] = [
      '#title' => $this->t("Classes to be added"),
      '#type' => 'textfield',
      '#description' => $this->t("Customize the styling of all blocks by adding CSS classes. Separate multiple classes by spaces."),
      '#states' => [
        'visible' => [
          ':input[name="operation"]' => [
            'value' => 'insert',
          ],
        ],
        'required' => [
          ':input[name="operation"]' => [
            'value' => 'insert',
          ],
        ],
      ],
    ];

    $form['current_class'] = [
      '#title' => $this->t("Current class"),
      '#type' => 'textfield',
      '#states' => [
        'visible' => [
          ':input[name="operation"]' => [
            'value' => 'update',
          ],
        ],
        'required' => [
          ':input[name="operation"]' => [
            'value' => 'update',
          ],
        ],
      ],
    ];

    $form['new_class'] = [
      '#title' => $this->t("New class"),
      '#type' => 'textfield',
      '#states' => [
        'visible' => [
          ':input[name="operation"]' => [
            'value' => 'update',
          ],
        ],
        'required' => [
          ':input[name="operation"]' => [
            'value' => 'update',
          ],
        ],
      ],
    ];

    $form['actions'] = [
      '#type' => 'actions',
    ];

    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Run'),
    ];

    return $form;

  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

    // Get the operation type.
    $operation = $form_state->getValue('operation');

    $parameters = [
      'operation' => $operation,
      'classes_to_be_added' => 0,
      'current_class' => 0,
      'new_class' => 0,
    ];

    // Get the classes to be added.
    if (!empty($form_state->getValue('classes_to_be_added'))) {
      $classes_to_be_added = $form_state->getValue('classes_to_be_added');
      $parameters['classes_to_be_added'] = $classes_to_be_added;
    }

    // Get the current class.
    if (!empty($form_state->getValue('current_class'))) {
      $current_class = $form_state->getValue('current_class');
      $parameters['current_class'] = $current_class;
    }

    // Get the new class.
    if (!empty($form_state->getValue('new_class'))) {
      $new_class = $form_state->getValue('new_class');
      $parameters['new_class'] = $new_class;
    }

    // Set session to confirm bulk operation. This session will be used on
    // confirmation page. So we'll show the confirmation only for users with
    // this session. @Todo: We'll implement the DI in a separated ticket.
    \Drupal::service('session')->set('block_class_confirm_bulk_operation', $operation);

    // Get path confirmation bulk operation.
    $path_confirm_bulk_operation = Url::fromRoute('block_class.confirm_bulk_operation', $parameters)->toString();

    // Get response.
    $response = new RedirectResponse($path_confirm_bulk_operation);

    // Send to confirmation.
    $response->send();
    exit;

  }

}
