<?php

namespace Drupal\block_class\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * Form for Block Class Settings.
 */
class BlockClassSettingsForm extends ConfigFormBase {

  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'block_class_admin_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'block_class.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $config = $this->config('block_class.settings');

    $form['global_settings'] = [
      '#type' => 'details',
      '#title' => $this->t('Global Settings'),
      '#open' => TRUE,
    ];

    $field_type = 'textfield';

    if (!empty($config->get('field_type'))) {
      $field_type = $config->get('field_type');
    }

    $form['global_settings']['field_type'] = [
      '#title' => $this->t("Field Type"),
      '#type' => 'select',
      '#options' => [
        'textfield' => $this->t('textfield'),
        'textarea' => $this->t('textarea'),
      ],
      '#default_value' => $field_type,
    ];

    $maxlength_block_class_field = 255;

    if (!empty($config->get('maxlength_block_class_field'))) {
      $maxlength_block_class_field = $config->get('maxlength_block_class_field');
    }

    $form['global_settings']['maxlength_block_class_field'] = [
      '#title' => $this->t("Maxlength on block class field"),
      '#type' => 'number',
      '#description' => $this->t('This will be the default maxlength value for the "maxlength" field. The default is 255.'),
      '#default_value' => $maxlength_block_class_field,
    ];

    $form['actions'] = [
      '#type' => 'actions',
    ];

    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Submit'),
    ];

    return $form;

  }

  /**
   * Validate the maxlength field.
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {

    parent::validateForm($form, $form_state);

    // Get the maxlength_block_class_field field.
    $maxlength_block_class_field = $form_state->getValue('maxlength_block_class_field');

    // Verify if is a positive value.
    if ($maxlength_block_class_field < 1) {
      $form_state->setErrorByName('maxlength_block_class_field', $this->t('The maxlength should be an positive value'));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

    // Get the field type.
    $field_type = $form_state->getValue('field_type');

    // Get the maxlength_block_class_field field.
    $maxlength_block_class_field = $form_state->getValue('maxlength_block_class_field');

    // Get the config object.
    $config = $this->config('block_class.settings');

    // Set the values.
    $config->set('field_type', $field_type);
    $config->set('maxlength_block_class_field', $maxlength_block_class_field);

    // Save that.
    $config->save();

    parent::submitForm($form, $form_state);
  }

}
